@@ -861,6 +861,20 @@ class AppHandler(object):
             self.vendor_handler = factory(self.config, **kwargs)
         return self.vendor_handler
 
+    def get_workorder_handler(self, **kwargs):
+        """
+        Get the configured "work order" handler.
+
+        :returns: The :class:`~rattail.workorders.WorkOrderHandler`
+           instance for the app.
+        """
+        if not hasattr(self, 'workorder_handler'):
+            spec = self.config.get('rattail', 'workorders.handler',
+                                   default='rattail.workorders:WorkOrderHandler')
+            Handler = self.load_object(spec)
+            self.workorder_handler = Handler(self.config)
+        return self.workorder_handler
+
     def progress_loop(self, *args, **kwargs):
         """
         Run a given function for a given sequence, and optionally show
@@ -1326,6 +1340,122 @@ class GenericHandler(object):
         return self.app.cache_model(session, model, **kwargs)
 
 
+class MergeMixin(object):
+    """
+    Mixin class for feature handlers supporting a record merge.
+    """
+
+    def make_merge_field(self, name, **kwargs):
+        field = {'name': name}
+        field.update(kwargs)
+        return field
+
+    def get_merge_preview_fields(self, **kwargs):
+        """
+        Returns a sequence of fields which will be used during a merge
+        preview.
+        """
+        F = self.make_merge_field
+        return [
+            F('uuid'),
+        ]
+
+    def get_merge_preview_data(self, obj, **kwargs):
+        """
+        Must return a data dictionary for the given object, which can
+        be presented to the user during a merge preview.
+        """
+        return {
+            'uuid': obj.uuid,
+        }
+
+    def get_merge_resulting_data(self, removing, keeping, **kwargs):
+        """
+        Must return a dictionary to represent what the *final* data
+        would look like, should the proposed merge occur.  Note that
+        we're still in preview mode here, this doesn't actually cause
+        any particular data to become final.
+
+        :param removing: Data dictionary for the object to be removed,
+           as obtained via :meth:`get_merge_preview_data()`.
+        :param keeping: Data dictionary for the object to be
+           preserved, as obtained via :meth:`get_merge_preview_data()`.
+        """
+        fields = self.get_merge_preview_fields()
+        coalesce_fields = [f for f in fields
+                           if f.get('coalesce')]
+        additive_fields = [f for f in fields
+                           if f.get('additive')]
+
+        # start with clone of the `keeping` dict
+        result = dict(keeping)
+
+        # coalesce any field values which need it
+        for field in coalesce_fields:
+            if removing[field] is not None and keeping[field] is None:
+                result[field] = removing[field]
+            elif removing[field] and not keeping[field]:
+                result[field] = removing[field]
+
+        # sum any field values which need it
+        for field in additive_fields:
+            if isinstance(keeping[field], (list, tuple)):
+                result[field] = sorted(set(removing[field] + keeping[field]))
+            else:
+                result[field] = removing[field] + keeping[field]
+
+        return result
+
+    def why_not_merge(self, removing, keeping, **kwargs):
+        """
+        Evaluate the given merge candidates and if there is a reason *not*
+        to merge them, return that reason.
+
+        :param removing: Object which will be removed, should the
+           merge happen.
+        :param keeping: Object which will be kept, should the merge
+           happen.
+        :returns: String indicating reason not to merge, or ``None``.
+        """
+
+    def perform_merge(self, removing, keeping, **kwargs):
+        """
+        Perform an actual merge of the 2 given objects.
+
+        :param removing: Object which should be removed.
+        :param keeping: Object which should be kept.
+        """
+        session = self.app.get_session(keeping)
+
+        # update the object to be kept, as needed
+        self.merge_update_keeping_object(removing, keeping)
+
+        # delete the unwanted object
+        session.delete(removing)
+        session.flush()
+
+    def merge_update_keeping_object(self, removing, keeping):
+        """
+        Update the object to be kept, with any relevant data from the
+        object to be removed, in the context of a merge.
+        """
+        for field in self.get_merge_preview_fields():
+
+            # fields which are "coalesced" require particular handling
+            if field.get('coalesce'):
+
+                # but we only support "simple" fields for this
+                if hasattr(keeping, field['name']):
+
+                    # if object to be kept does *not* have a value,
+                    # but object to be removed *does* have a value,
+                    # then overwrite value for the object to be kept
+                    removing_value = getattr(removing, field['name'])
+                    keeping_value = getattr(keeping, field['name'])
+                    if removing_value and not keeping_value:
+                        setattr(keeping, field['name'], removing_value)
+
+
 def make_app(config, **kwargs): # pragma: no cover
     warnings.warn("function is deprecated, please use "
                   "RattailConfig.get_app() method instead",
