@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -217,8 +217,8 @@ class PhoneMagicMixin(object):
         column = getattr(self.model_class, self.autocomplete_fieldname)
 
         # define the base query
-        query = session.query(self.model_class)\
-                       .options(orm.joinedload(self.model_class.phones))
+        query = self.make_base_query(session)\
+                    .options(orm.joinedload(self.model_class.phones))
 
         # does search term look like a phone number?
         phone_term = self.get_phone_search_term(term)
