@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -86,8 +86,7 @@ class MakeBatch(Action):
             session.flush()
             if not batch.data_rows:
                 log.debug("auto-deleting empty '{}' batch: {}".format(handler.batch_key, batch))
-                batch.delete_data(self.config)
-                session.delete(batch)
+                handler.do_delete(batch)
                 batch = None
 
         if batch and parse_bool(auto_execute_allowed) and handler.auto_executable(batch):
