@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,23 +28,31 @@ from __future__ import unicode_literals, absolute_import
 
 import os
 import datetime
+import logging
+import warnings
+from email import message_from_string
 from email.utils import parsedate_tz, mktime_tz
 
 import six
 from sqlalchemy import orm
 from flufl.bounce import all_failures
 
-from rattail.db import model
 from rattail.core import Object
 from rattail.util import load_object
 
 
-def get_handler(config, key):
+log = logging.getLogger(__name__)
+
+
+def get_handler(config, key): # pragma: no cover
     """
     Return a bounce handler instance as specified by configuration.
     """
-    spec = config.get('rattail.bouncer', '{0}.handler'.format(key)) or 'rattail.bouncer:BounceHandler'
-    return load_object(spec)(config, key)
+    warnings.warn("function is deprecated; please use "
+                  "`app.get_bounce_handler() instead",
+                  DeprecationWarning)
+    app = config.get_app()
+    return app.get_bounce_handler(key)
 
 
 class Link(Object):
@@ -62,6 +70,9 @@ class BounceHandler(object):
     def __init__(self, config, config_key):
         self.config = config
         self.config_key = config_key
+        self.app = config.get_app()
+        self.model = config.get_model()
+        self.enum = config.get_enum()
 
     def get_all_failures(self, msg):
         warnings, failures = all_failures(msg)
@@ -101,7 +112,39 @@ class BounceHandler(object):
     def msgpath(self, bounce):
         return os.path.join(self.msgdir(bounce), 'bounce.eml')
 
+    def handle_bounce_file(self, path, **kwargs):
+        """
+        Fully "handle" the given email message file, acting on it as
+        needed, depending on whether or not it is actually considered
+        to be a bounce etc.
+        """
+        with open(path, 'rt') as f:
+            text = f.read()
+        msg = message_from_string(text)
+
+        warnings, failures = self.get_all_failures(msg)
+        if failures:
+            log.info("adding bounce for '%s': %s", path, failures)
+
+            session = self.app.make_session()
+            session.continuum_comment = "Received email bounce from {}".format(
+                failures)
+
+            bounce = self.make_bounce(msg, failures)
+            session.add(bounce)
+            session.flush()
+            self.store_message_file(bounce, text)
+            self.process_bounce(bounce)
+            session.commit()
+
+        elif warnings:
+            log.warning("found message delivery warning for '%s': %s",
+                        path, warnings)
+        else:
+            log.debug("found message with nothing interesting: %s", path)
+
     def make_bounce(self, msg, failures=None, **kwargs):
+        model = self.model
         if failures is None:
             failed = self.get_failures(msg)
         kwargs.setdefault('config_key', self.config_key)
@@ -132,6 +175,7 @@ class BounceHandler(object):
         return Link(**kwargs)
 
     def make_links(self, session, recipient):
+        model = self.model
 
         url = self.config.require('tailbone', 'url.customer')
         emails = session.query(model.CustomerEmailAddress).filter_by(address=recipient)
