@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,5 +26,5 @@ Console Commands
 
 from __future__ import unicode_literals, absolute_import
 
-from .core import main, Command, Subcommand, Dump, date_argument, list_argument
+from .core import main, Command, Subcommand, date_argument, list_argument
 from .importing import ImportSubcommand, ImportFromCSV, ImportFileSubcommand, ExportFileSubcommand
