@@ -364,7 +364,7 @@ class Backup(Subcommand):
                 'HOME': os.environ['HOME'],
                 'BORG_REPO': repo,
                 'BORG_PASSPHRASE': passphrase,
-                'BORG_REMOTE_PATH': remote_borg or '',
+                'BORG_REMOTE_PATH': remote_borg or 'borg',
             }
 
             # borg create
