@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -51,11 +51,25 @@ class BatchHandlerCommand(Subcommand):
                             "occur, but rollback (abort) the transaction at the end.")
 
     def get_handler(self, args):
-        from rattail.batch import get_batch_handler
+        """
+        Must return the batch handler to use, per the given ``args``
+        object.
 
-        handler = get_batch_handler(self.config, args.batch_type)
-        assert handler
-        return handler
+        Default logic assumes that ``args`` has a ``batch_type``
+        attribute, which determines which batch handler should be
+        used.  That is figured out by calling
+        :meth:`~rattail.app.AppHandler.get_batch_handler()` on the app
+        handler.
+
+        :param args: Reference to the
+           :class:`python:argparse.Namespace` instance, which was the
+           result of parsing the command line args.
+
+        :returns: Must return the batch handler.  This will be an
+           instance of some class which derives from
+           :class:`~rattail.batch.handlers.BatchHandler`.
+        """
+        return self.app.get_batch_handler(args.batch_type)
 
     def run(self, args):
         handler = self.get_handler(args)
