@@ -78,12 +78,12 @@ class DataSync(Subcommand):
 
         parser.add_argument('-p', '--pidfile', metavar='PATH', default='/var/run/rattail/datasync.pid',
                             help="Path to PID file.")
-        parser.add_argument('--daemonize', action='store_true', default=True, # TODO: should default to False
-                            help="Daemonize when starting.")
+        parser.add_argument('--daemonize', action='store_true',
+                            help="DEPRECATED")
         parser.add_argument('--no-daemonize',
-                            '-D', '--do-not-daemonize', # TODO: (re)move these?
+                            '-D', '--do-not-daemonize',
                             action='store_false', dest='daemonize',
-                            help="Do not daemonize when starting.")
+                            help="DEPRECATED")
         parser.add_argument('-T', '--timeout', metavar='MINUTES', type=int, default=0,
                             help="Optional timeout (in minutes) for use with the 'wait' or 'check' commands.  "
                             "If specified for 'wait', the waiting still stop after the given number of minutes "
@@ -122,12 +122,9 @@ class DataSync(Subcommand):
                 daemon.stop()
             else: # start
                 try:
-                    daemon.start(daemonize=args.daemonize)
+                    daemon.start(daemonize=False)
                 except KeyboardInterrupt:
-                    if not args.daemonize:
-                        self.stderr.write("Interrupted.\n")
-                    else:
-                        raise
+                    self.stderr.write("Interrupted.\n")
 
     def wait(self, args):
         model = self.model
