@@ -150,6 +150,7 @@ class RattailConfig(object):
             from beaker.util import parse_cache_config_options
 
             # default cache settings
+            namespace = None
             options = {
                 'cache.type': 'file',
                 'cache.data_dir': os.path.join(self.appdir(), 'cache',
@@ -161,6 +162,9 @@ class RattailConfig(object):
             # but let config override and supplement
             if self.parser.has_section('rattail.config'):
                 for option in self.parser.options('rattail.config'):
+                    if option == 'beaker_cache.namespace':
+                        namespace = self.parser.get('rattail.config', option)
+                        continue
                     prefix = 'beaker_cache.'
                     if option.startswith(prefix):
                         key = 'cache.{}'.format(option[len(prefix):])
@@ -170,10 +174,19 @@ class RattailConfig(object):
             self.beaker_cache_manager = CacheManager(
                 **parse_cache_config_options(options))
 
-            # our namespace is pretty normal...but on python2, and
+            # use app-specific namespace in case multiple apps use the
+            # same (e.g. memcached) backend.  note that we're making a
+            # "best faith" effort here; using the name of the python
+            # environment root dir.
+            if not namespace:
+                appdir = self.appdir()
+                rootdir = os.path.dirname(appdir)
+                envname = os.path.basename(rootdir)
+                namespace = 'rattail.config:{}'.format(envname)
+
+            # our namespace is just a string...but on python2, and
             # using memcached as backend, there is an encoding gotcha,
             # which we must fix here
-            namespace = 'rattail.config'
             if six.PY2:
                 namespace = namespace.encode('utf_8')
 
