@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,6 +24,8 @@
 "Generic" Catalog Parser
 """
 
+from __future__ import unicode_literals, absolute_import
+
 import datetime
 import decimal
 import logging
@@ -32,9 +34,6 @@ import six
 
 from rattail.vendors.catalogs import CatalogParser
 from rattail.excel import ExcelReaderXLSX
-from rattail.db import model
-from rattail.gpc import GPC
-from rattail.time import localtime, make_utc
 
 
 log = logging.getLogger(__name__)
@@ -55,15 +54,14 @@ class GenericCatalogParser(CatalogParser):
         xlrows = reader.read_rows(progress=progress)
 
         for xlrow in xlrows:
-            row = model.VendorCatalogBatchRow()
+            row = self.make_row()
 
             # upc (required)
             upc = xlrow['UPC']
             if not upc or not six.text_type(upc).strip():
                 continue        # skip lines with no UPC value
-            upc = str(upc).replace(' ', '').replace('-', '')
             row.item_entry = upc
-            row.upc = GPC(upc, calc_check_digit=False if len(upc) in (12, 13) else 'upc')
+            row.upc = self.app.make_gpc(upc)
 
             # cost values (required in some combination)
             if 'Case Cost' in xlrow:
@@ -73,7 +71,9 @@ class GenericCatalogParser(CatalogParser):
                 else:
                     row.case_cost = self.decimal(case_cost)
             if 'Case Size' in xlrow:
-                row.case_size = int(xlrow['Case Size'])
+                case_size = xlrow['Case Size']
+                if case_size is not None and case_size != '':
+                    row.case_size = int(case_size)
             if 'Unit Cost' in xlrow:
                 row.unit_cost = self.decimal(xlrow['Unit Cost'])
             elif row.case_cost and row.case_size:
@@ -81,7 +81,10 @@ class GenericCatalogParser(CatalogParser):
 
             # optional values
             if 'Vendor Code' in xlrow:
-                row.vendor_code = six.text_type(xlrow['Vendor Code'])
+                vendor_code = xlrow['Vendor Code']
+                if vendor_code is not None:
+                    row.vendor_code = six.text_type(vendor_code)
+
             if 'Brand' in xlrow:
                 row.brand_name = xlrow['Brand']
             if 'Description' in xlrow:
@@ -100,19 +103,19 @@ class GenericCatalogParser(CatalogParser):
             if 'Vendor Discount Start Date' in xlrow:
                 row.discount_starts = xlrow['Vendor Discount Start Date']
                 if row.discount_starts: # must convert to UTC, at local midnight
-                    date = localtime(self.config, row.discount_starts).date()
+                    date = self.app.localtime(row.discount_starts).date()
                     starts = datetime.datetime.combine(date, datetime.time(0))
-                    starts = localtime(self.config, starts)
-                    row.discount_starts = make_utc(starts)
+                    starts = self.app.localtime(starts)
+                    row.discount_starts = self.app.make_utc(starts)
 
             # discount_ends
             if 'Vendor Discount End Date' in xlrow:
                 row.discount_ends = xlrow['Vendor Discount End Date']
                 if row.discount_ends: # must convert to UTC, 1 minute shy of local midnight
-                    date = localtime(self.config, row.discount_ends).date()
+                    date = self.app.localtime(row.discount_ends).date()
                     ends = datetime.datetime.combine(date, datetime.time(23, 59))
-                    ends = localtime(self.config, ends)
-                    row.discount_ends = make_utc(ends)
+                    ends = self.app.localtime(ends)
+                    row.discount_ends = self.app.make_utc(ends)
 
             # discount_amount
             if 'Vendor Discount Amount' in xlrow:
