@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -72,7 +72,7 @@ class LotusLightCatalogParser(CatalogParser):
         sheet = book.sheet_by_index(0)
         for i in range(1, sheet.nrows): # skip first header row
 
-            row = model.VendorCatalogRow()
+            row = model.VendorCatalogBatchRow()
 
             upc = sheet.cell_value(i, 1)
             if upc:
