@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
+# -*- coding: utf-8; -*-
 """
 Data model for ${model_title} batches
 """
@@ -10,12 +10,10 @@ import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.declarative import declared_attr
 
-from rattail.db.model import Base
-from rattail.db.batch.model import FileBatchMixin, ProductBatchRowMixin
-from rattail.db.types import GPCType
+from rattail.db import model
 
 
-class ${model_name}(FileBatchMixin, Base):
+class ${model_name}(model.FileBatchMixin, model.Base):
     """
     Primary data model for ${model_title} batches.
     """
@@ -45,7 +43,7 @@ class ${model_name}(FileBatchMixin, Base):
     """)
 
 
-class ${model_name}Row(ProductBatchRowMixin, Base):
+class ${model_name}Row(model.ProductBatchRowMixin, model.Base):
     """
     Row of data within a ${model_title} batch.
     """
@@ -72,7 +70,7 @@ class ${model_name}Row(ProductBatchRowMixin, Base):
         STATUS_UTTER_CHAOS:     "the world just ended",
     }
 
-    upc = sa.Column(GPCType(), nullable=True, doc="""
+    upc = sa.Column(model.GPCType(), nullable=True, doc="""
     UPC for the row.
     """)
 
