@@ -31,7 +31,6 @@ import time
 import logging
 from traceback import format_exception
 
-from rattail.db import api
 from rattail.daemon import Daemon
 from rattail.threads import Thread
 from rattail.datasync.config import load_profiles
@@ -189,11 +188,21 @@ def watch_for_changes(config, watcher):
                 # record new lastrun time
                 lastrun = thisrun
                 try:
-                    api.save_setting(None, lastrun_setting,
-                                     lastrun.strftime(timefmt))
+                    session = app.make_session()
                 except:
-                    log.exception("failed to save lastrun time")
+                    log.exception("failed to make session, to save lastrun time")
                     raise
+                else:
+                    try:
+                        app.save_setting(session, lastrun_setting,
+                                         lastrun.strftime(timefmt))
+                        session.commit()
+                    except:
+                        session.rollback()
+                        log.exception("failed to save lastrun time")
+                        raise
+                    finally:
+                        session.close()
 
                 if changes:
                     log.debug("got %s changes from watcher", len(changes))
@@ -563,7 +572,8 @@ def consume_changes_from(config, session, consumer, obtained):
     # maybe limit size of batch to process.  this can be useful e.g. when large
     # amounts of changes land in the queue with same timestamp, and versioning
     # is also enabled.
-    batch_size = config.getint('rattail.datasync', 'batch_size_limit')
+    batch_size = config.getint('rattail.datasync', 'batch_size_limit',
+                               session=session)
     if batch_size and len(changes) > batch_size:
         changes = changes[:batch_size]
 
@@ -593,7 +603,7 @@ def consume_changes_from(config, session, consumer, obtained):
                     'error': exc,
                     'attempts': attempts,
                     'traceback': ''.join(format_exception(exc_type, exc, traceback)).strip(),
-                    'datasync_url': config.datasync_url(),
+                    'datasync_url': config.datasync_url(session=session),
                 })
                 return False
 
@@ -648,7 +658,7 @@ def consume_changes_from(config, session, consumer, obtained):
                     'error': exc,
                     'attempts': attempts,
                     'traceback': ''.join(format_exception(exc_type, exc, traceback)).strip(),
-                    'datasync_url': config.datasync_url(),
+                    'datasync_url': config.datasync_url(session=session),
                 })
                 return False
 
