@@ -18,10 +18,10 @@ from rattail.db.continuum import configure_versioning
 alembic_config = context.config
 
 # Use same config file for Rattail, as we are for Alembic.
-rattail_config = make_config(alembic_config.config_file_name)
+rattail_config = make_config(alembic_config.config_file_name, versioning=False)
 
 # Configure Continuum...this is trickier than I'd like.
-configure_versioning(rattail_config)
+configure_versioning(rattail_config, force=True)
 from rattail.db import model
 configure_mappers()
 
