@@ -31,16 +31,10 @@ def upgrade():
     op.execute(CreateSequence(batch_id_seq))
 
     # vendor_catalog
-    op.add_column('vendor_catalog', sa.Column('id', sa.Integer(), batch_id_seq, nullable=True))
-    vendor_catalog = sa.sql.table('vendor_catalog', sa.sql.column('id'))
-    op.execute(vendor_catalog.update().values({'id': batch_id_seq.next_value()}))
-    op.alter_column('vendor_catalog', 'id', nullable=False)
+    op.add_column('vendor_catalog', sa.Column('id', sa.Integer(), nullable=False))
 
     # vendor_invoice
-    op.add_column('vendor_invoice', sa.Column('id', sa.Integer(), batch_id_seq, nullable=True))
-    vendor_invoice = sa.sql.table('vendor_invoice', sa.sql.column('id'))
-    op.execute(vendor_invoice.update().values({'id': batch_id_seq.next_value()}))
-    op.alter_column('vendor_invoice', 'id', nullable=False)
+    op.add_column('vendor_invoice', sa.Column('id', sa.Integer(), nullable=False))
 
 
 def downgrade():
