@@ -27,7 +27,8 @@ def upgrade():
     op.add_column('product', sa.Column('discountable', sa.Boolean(), nullable=True))
     product = sa.sql.table('product', sa.sql.column('discountable'))
     op.execute(product.update().values({'discountable': True}))
-    op.alter_column('product', 'discountable', nullable=False)
+    op.alter_column('product', 'discountable', nullable=False,
+                    existing_type=sa.Boolean())
     op.add_column('product_version', sa.Column('discountable', sa.Boolean(), nullable=True))
 
 
