@@ -28,7 +28,8 @@ def upgrade():
     op.add_column('customer_version', sa.Column('active_in_pos_sticky', sa.Boolean(), autoincrement=False, nullable=True))
     customer = sa.sql.table('customer', sa.sql.column('active_in_pos_sticky'))
     op.execute(customer.update().values({'active_in_pos_sticky': False}))
-    op.alter_column('customer', 'active_in_pos_sticky', nullable=False)
+    op.alter_column('customer', 'active_in_pos_sticky', nullable=False,
+                    existing_type=sa.Boolean())
 
 
 def downgrade():
