@@ -27,7 +27,8 @@ def upgrade():
     op.add_column('vendor_catalog_row', sa.Column('department_name', sa.String(length=30), nullable=True))
     op.add_column('vendor_catalog_row', sa.Column('department_number', sa.Integer(), nullable=True))
     op.add_column('vendor_catalog_row', sa.Column('item_id', sa.String(length=20), nullable=True))
-    op.alter_column('vendor_catalog_row', 'description', nullable=True)
+    op.alter_column('vendor_catalog_row', 'description', nullable=True,
+                    existing_type=sa.String(length=255))
 
 
 def downgrade():
