@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2019 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,12 +26,18 @@ Products API
 
 from __future__ import unicode_literals, absolute_import
 
+import logging
+
+from sqlalchemy import orm
 from sqlalchemy.orm.exc import NoResultFound
 
 from rattail import enum
 from rattail.db import model
 
 
+log = logging.getLogger(__name__)
+
+
 def get_product_by_upc(session, upc, include_deleted=False):
     """
     Returns the :class:`rattail.Product` associated with ``upc`` (if found), or
@@ -46,6 +52,34 @@ def get_product_by_upc(session, upc, include_deleted=False):
         pass
 
 
+def get_product_by_item_id(session, item_id, include_deleted=False):
+    """
+    Returns the :class:`rattail.Product` associated with ``item_id`` (if
+    found), or ``None``.
+    """
+    products = session.query(model.Product)
+    if not include_deleted:
+        products = products.filter(model.Product.deleted == False)
+    try:
+        return products.filter(model.Product.item_id == item_id).one()
+    except NoResultFound:
+        pass
+
+
+def get_product_by_scancode(session, scancode, include_deleted=False):
+    """
+    Returns the :class:`rattail.Product` associated with ``scancode`` (if
+    found), or ``None``.
+    """
+    products = session.query(model.Product)
+    if not include_deleted:
+        products = products.filter(model.Product.deleted == False)
+    try:
+        return products.filter(model.Product.scancode == scancode).one()
+    except NoResultFound:
+        pass
+
+
 def get_product_by_code(session, code, include_deleted=False):
     """
     Locate a ``Product`` instance using a code value.
@@ -146,3 +180,42 @@ def set_current_sale_price(product, newprice, starts=None, ends=None, **kwargs):
         product.prices.append(price)
     product.current_price = price
     return price
+
+
+future_cost_fieldmap = {
+    'order_code': 'code',
+    'case_quantity': 'case_size',
+    'case_cost': 'case_cost',
+    'unit_cost': 'unit_cost',
+    'starts': 'effective',
+    'discontinued': 'discontinued',
+}
+
+
+def make_future_cost_current(config, future):
+    """
+    Take the given future cost, and make it current.
+    """
+    if not future.cost:
+        raise NotImplementedError("don't know how to create costs yet")
+
+    cost = future.cost
+
+    if not future.product:
+        raise ValueError("future cost does not have product association: {}".format(future))
+
+    if not future.vendor:
+        raise ValueError("future cost does not have vendor association: {}".format(future))
+
+    if future.product is not cost.product:
+        raise ValueError("product mismatch for future/current costs: {}".format(future))
+
+    if future.vendor is not cost.vendor:
+        raise ValueError("vendor mismatch for future/current costs: {}".format(future))
+
+    for field in future_cost_fieldmap:
+        setattr(cost, future_cost_fieldmap[field], getattr(future, field))
+
+    session = orm.object_session(future)
+    session.delete(future)
+    log.debug("future cost became current: %s", cost)
