@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -33,6 +33,7 @@ from sqlalchemy.orm import joinedload
 
 from rattail.core import Object
 from rattail.db import model
+from rattail.util import OrderedDict
 
 
 log = logging.getLogger(__name__)
@@ -88,7 +89,7 @@ class ModelCacher(object):
         return q
 
     def get_cache(self, progress):
-        self.instances = {}
+        self.instances = OrderedDict()
         query = self.query()
         count = query.count()
         if not count:
