@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -256,8 +256,8 @@ class ChangeRecorder(object):
                            class_name=instance.__class__.__name__,
                            instance_uuid=instance.uuid,
                            deleted=type_ == 'deleted')
-        log.debug("recorded change for {} {} {}: {}".format(
-            type_, instance.__class__.__name__, instance.uuid, instance))
+        log.debug("recorded change for %s %s %s: %s",
+                  type_, instance.__class__.__name__, instance.uuid, instance)
         return True
 
     def record_change(self, session, quiet=False, **kwargs):
