@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -195,11 +195,14 @@ class ContactMixin(object):
         Add a new "email" record to the contact.
         """
         flush = kwargs.pop('flush', True)
+        primary = kwargs.pop('primary', False)
         email = self.make_email(**kwargs)
         self.emails.append(email)
         if flush:
             session = orm.object_session(self)
             session.flush()
+        if primary:
+            self.set_primary_email(email, flush=flush)
         return email
 
     def set_primary_email(self, email, flush=True):
@@ -262,11 +265,14 @@ class ContactMixin(object):
         Add a new "phone" record to the contact.
         """
         flush = kwargs.pop('flush', True)
+        primary = kwargs.pop('primary', False)
         phone = self.make_phone(**kwargs)
         self.phones.append(phone)
         if flush:
             session = orm.object_session(self)
             session.flush()
+        if primary:
+            self.set_primary_phone(phone, flush=flush)
         return phone
 
     def remove_phone(self, phone, **kwargs):
