@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -67,6 +67,17 @@ class ModelBase(Object):
 
         return "{0}({1})".format(self.__class__.__name__, ', '.join(keys))
 
+    def get_data_dict(self):
+        """
+        Return a simple data dict containing field values for all
+        table columns present for the object (row).
+
+        :returns: Dict of field data.
+        """
+        mapper = orm.object_mapper(self)
+        return dict([(prop.key, getattr(self, prop.key))
+                     for prop in mapper.column_attrs])
+
     @classmethod
     def get_model_title(cls):
         """
