@@ -84,7 +84,6 @@ class UnitOfMeasure(Base):
         return self.abbreviation or ""
 
 
-@six.python_2_unicode_compatible
 class Brand(Base):
     """
     Represents a brand or similar product line.
@@ -109,7 +108,14 @@ class Brand(Base):
     """)
 
     def __str__(self):
-        return self.name or ''
+        text = self.name or ''
+        if six.PY2:
+            return text.encode('utf8')
+        return text
+
+    if six.PY2:
+        def __unicode__(self):
+            return self.name or ''
 
 
 @six.python_2_unicode_compatible
