@@ -238,6 +238,10 @@ class PurchaseItemBase(object):
     Expected cost per single unit of product, as of initial order placement.
     """)
 
+    po_case_size = sa.Column(sa.Numeric(precision=8, scale=2), nullable=True, doc="""
+    Number of units in a single case of product, according to PO.
+    """)
+
     po_total = sa.Column(sa.Numeric(precision=7, scale=2), nullable=True, doc="""
     Total cost for the line item, according to the initial purchase order.
     """)
@@ -275,6 +279,10 @@ class PurchaseItemBase(object):
     Actual cost per single unit of product, per invoice.
     """)
 
+    invoice_case_size = sa.Column(sa.Numeric(precision=8, scale=2), nullable=True, doc="""
+    Number of units in a single case of product, according to invoice.
+    """)
+
     invoice_total = sa.Column(sa.Numeric(precision=7, scale=2), nullable=True, doc="""
     Total cost for the line item, according to the invoice.
     """)
@@ -303,6 +311,14 @@ class PurchaseItemBase(object):
     Number of units of product for which mispick was shipped.
     """)
 
+    cases_missing = sa.Column(sa.Numeric(precision=10, scale=4), nullable=True, doc="""
+    Number of cases of product which were ultimately missing.
+    """)
+
+    units_missing = sa.Column(sa.Numeric(precision=10, scale=4), nullable=True, doc="""
+    Number of units of product which were ultimately missing.
+    """)
+
 
 @six.python_2_unicode_compatible
 class PurchaseCreditBase(object):
@@ -364,7 +380,7 @@ class PurchaseCreditBase(object):
     """)
 
     credit_type = sa.Column(sa.String(length=20), nullable=False, doc="""
-    Type of the credit, i.e. damaged/expired/mispick
+    Type of the credit, i.e. damaged/expired/mispick/missing
     """)
 
     product_uuid = sa.Column(sa.String(length=32), nullable=True)
