@@ -74,6 +74,11 @@ class Store(Base):
         phone = StorePhoneNumber(number=number, type=type)
         self.phones.append(phone)
 
+    # TODO: this class should use ContactMixin instead
+    def first_phone(self, **kwargs):
+        if self.phones:
+            return self.phones[0]
+
 
 class StorePhoneNumber(PhoneNumber):
     """
