@@ -50,7 +50,17 @@ class Vendor(Base):
     __versioned__ = {}
 
     uuid = uuid_column()
-    id = sa.Column(sa.String(length=15))
+
+    id = sa.Column(sa.String(length=15), nullable=True, doc="""
+    "Official" string ID for the vendor.  It is assumed / hoped that this will
+    be shared across systems where possible.
+    """)
+
+    abbreviation = sa.Column(sa.String(length=20), nullable=True, doc="""
+    Abbreviation for the vendor.  Whereas presumably the :attr:`id` would never
+    change, this abbreviation is expected to (possibly) change over time.
+    """)
+
     name = sa.Column(sa.String(length=50), nullable=True)
     special_discount = sa.Column(sa.Numeric(precision=5, scale=3))
 
@@ -81,6 +91,16 @@ class Vendor(Base):
         phone = VendorPhoneNumber(number=number, type=type)
         self.phones.append(phone)
 
+    def get_email(self, type_='Info'):
+        for email in self.emails:
+            if email.type == type_:
+                return email
+
+    def get_email_address(self, *args, **kwargs):
+        email = self.get_email(*args, **kwargs)
+        if email:
+            return email.address
+
     
 class VendorPhoneNumber(PhoneNumber):
     """
