@@ -355,6 +355,20 @@ class run_n_mail(CommandOutputEmail):
     fallback_key = None
 
 
+class sendmail_failure(Email):
+    """
+    This alert is sent whenever sending of another "normal" message fails.
+    """
+    default_subject = "Email Send Failed"
+
+    def sample_data(self, request):
+        return {
+            'attempt': "testing 1 2 3",
+            'message': {'To': 'fred@mailinator.com'},
+            'error': "Something went wrong!",
+        }
+
+
 class upgrade_failure(Email):
     """
     Sent when an app upgrade is attempted, but ultimately failed.
