@@ -127,7 +127,7 @@ class ExcelReaderXLSX(object):
     """
 
     def __init__(self, path, header_row=1, strip_fieldnames=True,
-                 **kwargs):
+                 datefmt='%Y-%m-%d', **kwargs):
         """
         Constructor; opens an Excel file for reading.
 
@@ -144,6 +144,7 @@ class ExcelReaderXLSX(object):
         self.sheet = self.book.active
 
         self.header_row = header_row
+        self.datefmt = datefmt
 
         self.fields = None
         # TODO: this seems like a hacky way to get the header fields?  we are
@@ -182,6 +183,10 @@ class ExcelReaderXLSX(object):
     # the older xlrd-based reader above.  maybe should just deprecate
     # and/or remove it though
     def parse_date(self, value, fmt=None):
+        if isinstance(value, six.string_types):
+            if not value:
+                return
+            return datetime.datetime.strptime(value, fmt or self.datefmt).date()
         return value
 
 
