@@ -179,3 +179,10 @@ class PalmConduitNotRegistered(PalmError):
 
     def __str__(self):
         return "The Rattail Palm conduit is not registered."
+
+
+class StopProcessing(RattailError):
+    """
+    Simple exception to indicate action processing should stop.  This
+    is probably only useful for tests.
+    """
