@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,12 @@
 File Monitor for Windows
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import os
 import time
 import datetime
-import Queue
+from six.moves import queue
 import logging
 
 from rattail.win32.service import Service
@@ -68,10 +68,10 @@ class RattailFileMonitor(Service):
             return False
 
         # Create monitor and action threads for each profile.
-        for key, profile in self.monitored.iteritems():
+        for key, profile in self.monitored.items():
 
             # Create a file queue for the profile.
-            profile.queue = Queue.Queue()
+            profile.queue = queue.Queue()
 
             # Perform setup for each of the watched folders.
             for i, path in enumerate(profile.dirs, 1):
