@@ -631,6 +631,14 @@ class Importer(object):
                 return data['object'] if data else None
             return self.get_single_local_object(key)
 
+    def get_single_host_object(self, key):
+        """
+        Must return the host object corresponding to the given key, or
+        None.  This method should not consult the cache; it is meant
+        to be called within datasync or other "one-off" scenarios.
+        """
+        raise NotImplementedError
+
     def get_single_local_object(self, key):
         """
         Must return the local object corresponding to the given key, or None.
