@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -368,6 +368,8 @@ class GlobalRoleImporter(RoleImporter):
                         changed = True
 
             if changed:
+                self.session.flush()
+                self.session.refresh(role)
                 # also record a change to the role, for datasync.
                 # this is done "just in case" the role is to be
                 # synced to all nodes
