@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2019 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,10 +28,10 @@ from __future__ import unicode_literals, absolute_import
 
 from rattail import importing
 from rattail.util import OrderedDict
-from rattail.importing.rattail import FromRattailToRattail, FromRattail
+from rattail.importing.rattail import FromRattailToRattailImport, FromRattail
 
 
-class BulkFromRattailToRattail(FromRattailToRattail, importing.BulkImportHandler):
+class BulkFromRattailToRattail(FromRattailToRattailImport, importing.BulkImportHandler):
     """
     Handler for Rattail -> Rattail bulk data import.
     """
