@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -33,6 +33,7 @@ import datetime
 import socket
 import getpass
 import logging
+import warnings
 
 import pytz
 
@@ -68,6 +69,10 @@ class RattailAdapter(logging.LoggerAdapter):
         # use super() in case we're running on Python 2.6.
         logging.LoggerAdapter.__init__(self, logger, extra)
 
+        warnings.warn("rattail.logging.RattailAdapter is deprecated, "
+                      "please do not use!",
+                      DeprecationWarning)
+
     def process(self, msg, kwargs):
         extra = dict(self.extra)
         extra.update(kwargs.get('extra', {}))
@@ -83,6 +88,9 @@ def get_logger(name):
     function.  It does the same thing, except for wrapping the logger within a
     :class:`RattailAdapter`.
     """
+    warnings.warn("rattail.logging.get_logger() is deprecated, "
+                  "please do not use!",
+                  DeprecationWarning)
     log = logging.getLogger(name)
     return RattailAdapter(log)
 
