@@ -71,7 +71,7 @@ def send_email(config, key, data={}, attachments=[],
                               default_subject=default_subject)
 
     if enabled is UNSPECIFIED:
-        enabled = handler.get_enabled(email)
+        enabled = handler.email_is_enabled(email)
 
     if enabled:
         kwargs['attachments'] = attachments
@@ -87,6 +87,8 @@ class EmailHandler(object):
 
     def __init__(self, config):
         self.config = config
+        self.app = config.get_app()
+        self.model = self.config.get_model()
         self.enum = self.config.get_enum()
 
     def use_entry_points(self):
@@ -98,6 +100,22 @@ class EmailHandler(object):
         return self.config.getbool('rattail.mail', 'emails.use_entry_points',
                                    default=False)
 
+    def should_record_attempts(self):
+        """
+        Returns a boolean indicating if the app should make a record
+        of all attempts to send email.
+        """
+        return self.config.getbool('rattail.mail', 'record_attempts',
+                                   default=False)
+
+    def should_send_email_on_failure(self):
+        """
+        Returns a boolean indicating if the app should send an email
+        alert whenever sending of an email message fails.
+        """
+        return self.config.getbool('rattail.mail', 'send_email_on_failure',
+                                   default=False)
+
     def get_all_emails(self, **kwargs):
         """
         Retrieve the complete set of all Email profiles exposed by the
@@ -149,13 +167,6 @@ class EmailHandler(object):
         Retrieve the set of "available" Email profiles, i.e. those
         which should be exposed to the app users.
         """
-        # TODO: maybe deprecate this at some point?
-        if not self.use_entry_points():
-            # nb. this is the legacy behavior
-            return dict([(email.key or email.__name__, email)
-                         for email in self.iter_emails(warn=False)])
-
-        # this is the future
         emails = self.get_all_emails()
         for key in list(emails):
             if not self.email_is_available(key):
@@ -227,22 +238,22 @@ class EmailHandler(object):
     def send_message(self, email, data, **kwargs):
         msg = self.make_message(email, data, **kwargs)
 
-        if self.config.getbool('rattail.mail', 'record_attempts', default=False):
+        if self.should_record_attempts():
             attempt = self.record_attempt(email, msg)
             try:
                 self.deliver_message(email, msg)
             except Exception as e:
-                self.record_failure(attempt, e)
+                self.record_failure(email, msg, attempt, e)
+                raise
             else:
-                self.record_success(attempt)
+                self.record_success(email, msg, attempt)
 
         else: # don't record attempts
             self.deliver_message(email, msg)
 
     def record_attempt(self, email, msg):
-        from rattail.db import Session, model
-
-        session = Session()
+        model = self.model
+        session = self.app.make_session()
 
         attempt = model.EmailAttempt()
         attempt.key = email.key
@@ -253,27 +264,31 @@ class EmailHandler(object):
         attempt.subject = msg['Subject']
         attempt.sent = make_utc()
         attempt.status_code = self.enum.EMAIL_ATTEMPT_CREATED
-
         session.add(attempt)
+
         session.commit()
         session.close()
         # session.expunge(attempt)
         return attempt
 
-    def record_failure(self, attempt, error):
-        from rattail.db import Session
-
-        session = Session()
+    def record_failure(self, email, message, attempt, error):
+        session = self.app.make_session()
         attempt = session.merge(attempt)
         attempt.status_code = self.enum.EMAIL_ATTEMPT_FAILURE
         attempt.status_text = six.text_type(error)
         session.commit()
         session.close()
 
-    def record_success(self, attempt):
-        from rattail.db import Session
+        if self.should_send_email_on_failure():
+            self.app.send_email('sendmail_failure', {
+                'email': email,
+                'message': message,
+                'attempt': attempt,
+                'error': error,
+            })
 
-        session = Session()
+    def record_success(self, email, message, attempt):
+        session = self.app.make_session()
         attempt = session.merge(attempt)
         attempt.status_code = self.enum.EMAIL_ATTEMPT_SUCCESS
         session.commit()
