@@ -32,6 +32,24 @@ from rattail.config import ConfigProfile, parse_list
 from rattail.exceptions import ConfigurationError
 
 
+class MailMonitorAccountProfile(ConfigProfile):
+    """
+    Simple class to hold configuration specific to an "account" within
+    the MailMon setup.
+    """
+    section = 'rattail.mailmon'
+
+    def load(self):
+        self.server = self._config_string('server')
+        self.username = self._config_string('username')
+        self.password = self._config_string('password')
+        self.error_delay = self._config_int('error_delay',
+                                            minimum=0,
+                                            default=60)
+        self.recycle_delay = self._config_int('recycle_delay',
+                                              minimum=0)
+
+
 class MailMonitorProfile(ConfigProfile):
     """
     Simple class to hold configuration for a MailMon "profile".  Each
@@ -43,9 +61,7 @@ class MailMonitorProfile(ConfigProfile):
 
     def load(self):
 
-        self.imap_server = self._config_string('imap.server')
-        self.imap_username = self._config_string('imap.username')
-        self.imap_password = self._config_string('imap.password')
+        self.imap_account = self._config_string('imap.account')
         self.imap_folder = self._config_string('imap.folder')
         self.imap_unread_only = self._config_boolean('imap.unread_only')
         self.imap_delay = self._config_int('imap.delay', default=120)
@@ -70,24 +86,50 @@ def load_mailmon_profiles(config):
     """
     Load all active mail monitor profiles defined within configuration.
     """
-    # make sure we have a top-level directive
-    keys = config.get('rattail.mailmon', 'monitor')
-    if not keys:
+    # make sure we have our top-level directives
+    monitor_keys = config.get('rattail.mailmon', 'monitor')
+    if not monitor_keys:
         raise ConfigurationError(
             "The mail monitor configuration does not specify any profiles "
             "to be monitored.  Please defined the 'monitor' option within "
             "the [rattail.mailmon] section of your config file.")
+    account_keys = config.get('rattail.mailmon', 'accounts')
+    if not account_keys:
+        raise ConfigurationError(
+            "The mail monitor configuration does not specify any accounts "
+            "to which to connect.  Please defined the 'accounts' option within "
+            "the [rattail.mailmon] section of your config file.")
 
-    monitored = {}
-    for key in parse_list(keys):
+    # first load the accounts
+    accounts = {}
+    for key in parse_list(account_keys):
+        profile = MailMonitorAccountProfile(config, key,
+                                            prefix='account.{}'.format(key))
+        accounts[key] = profile
+
+    # now load the monitor profiles
+    monitored = {'__accounts__': accounts}
+    for key in parse_list(monitor_keys):
         profile = MailMonitorProfile(config, key)
 
-        # only monitor this profile if it validates
-        try:
-            profile.validate()
-        except ConfigurationError as error:
-            log.warning(six.text_type(error))
+        # only monitor this profile if it uses valid account
+        if profile.imap_account not in accounts:
+            log.warning("profile references invalid account (%s): %s",
+                        profile.imap_account, profile)
+
         else:
-            monitored[key] = profile
+            # only monitor this profile if it validates
+            try:
+                profile.validate()
+            except ConfigurationError as error:
+                log.warning(six.text_type(error))
+            else:
+                monitored[key] = profile
+
+    # finally let each account know what it should monitor
+    for account in six.itervalues(accounts):
+        account.monitored = [m for k, m in monitored.items()
+                             if k != '__accounts__'
+                             and m.imap_account == account.key]
 
     return monitored
