@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -48,6 +48,8 @@ class ProblemReport(object):
         self.config = config
         self.dry_run = dry_run
         self.progress = progress
+        self.app = self.config.get_app()
+        self.model = self.config.get_model()
         self.enum = self.config.get_enum()
 
     def progress_loop(self, func, items, factory=None, **kwargs):
