@@ -37,7 +37,7 @@ from sqlalchemy import orm
 from rattail import pod
 from rattail.db import api
 from rattail.util import load_object
-from rattail.app import GenericHandler
+from rattail.app import GenericHandler, MergeMixin
 from rattail.gpc import GPC
 from rattail.barcodes import upce_to_upca, upc_check_digit
 
@@ -45,7 +45,7 @@ from rattail.barcodes import upce_to_upca, upc_check_digit
 log = logging.getLogger(__name__)
 
 
-class ProductsHandler(GenericHandler):
+class ProductsHandler(GenericHandler, MergeMixin):
     """
     Base class and default implementation for product handlers.
 
@@ -982,6 +982,45 @@ class ProductsHandler(GenericHandler):
         """
         return []
 
+    def get_merge_preview_fields(self, **kwargs):
+        F = self.make_merge_field
+        return [
+            F('uuid'),
+            F('item_id'),
+            F('upc'),
+            F('brand_name'),
+            F('description'),
+            F('size'),
+            F('department_number'),
+            F('department_name'),
+            F('subdepartment_number'),
+            F('subdepartment_name'),
+            F('discontinued'),
+            F('deleted'),
+        ]
+
+    def get_merge_preview_data(self, product, **kwargs):
+        """
+        Must return a data dictionary for the given product, which can
+        be presented to the user during a merge preview.
+        """
+        department = product.department
+        subdepartment = product.subdepartment
+        return {
+            'uuid': product.uuid,
+            'item_id': product.item_id,
+            'upc': product.upc,
+            'brand_name': product.brand.name if product.brand else None,
+            'description': product.description,
+            'size': product.size,
+            'department_number': department.number if department else None,
+            'department_name': department.name if department else None,
+            'subdepartment_number': subdepartment.number if subdepartment else None,
+            'subdepartment_name': subdepartment.name if subdepartment else None,
+            'discontinued': product.discontinued,
+            'deleted': product.deleted,
+        }
+
 
 def get_products_handler(config, **kwargs):
     """
