@@ -161,4 +161,4 @@ class ExcelReport(Report):
 
         self.write_summary_sheet(writer, session, params, data, progress=progress)
 
-        writer.save()
+        writer.save(progress=progress)
