@@ -103,6 +103,10 @@ class ReportHandler(object):
         session.add(output)
         session.flush()
 
+        # nb. stash data for the report
+        # TODO: this is an undocumented feature...
+        output._generated_data = data
+
         path = output.filepath(self.config, makedirs=True)
         report.write_file(session, params, data, path, progress=progress, **kwargs)
         return output
