@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -121,6 +121,15 @@ class ExportTrainwreck(commands.ImportSubcommand):
         return kwargs
 
 
+class ImportSelf(ImportToTrainwreck):
+    """
+    Self-update for Trainwreck data
+    """
+    name = 'import-self'
+    description = __doc__.strip()
+    handler_key = 'to_trainwreck.from_self.import'
+
+
 class ImportTrainwreck(ImportToTrainwreck):
     """
     Import data from another Trainwreck database
