@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -183,6 +183,8 @@ class PDFInvoiceParser(InvoiceParser):
             template_dir = resource_path(template_dir)
             templates = read_templates(template_dir)
             result = extract_data(path, templates=templates)
+            if not result:
+                raise RuntimeError("could not find a matching template for the invoice!")
             self.extracted_pdf_data = result
 
         return self.extracted_pdf_data
